/*
 * Copyright 2021 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.hft.stuttgart.quality.model;

import org.citygml4j.builder.copy.CopyBuilder;
import org.citygml4j.builder.copy.ObjectCopier;

import java.util.ArrayList;
import java.util.List;

public class ErrorStatistics extends AbstractDataType {
    private int occurrences;
    private List<ErrorType> errors;

    public int getOccurrences() {
        return occurrences;
    }

    public void setOccurrences(int occurrences) {
        this.occurrences = occurrences;
    }

    public boolean isSetErrors() {
        return errors != null && !errors.isEmpty();
    }

    public List<ErrorType> getErrors() {
        if (errors == null) {
            errors = new ArrayList<>();
        }

        return errors;
    }

    public void setErrors(List<ErrorType> errors) {
        this.errors = errors;
    }

    @Override
    public Object copyTo(Object target, CopyBuilder copyBuilder) {
        ErrorStatistics copy = target == null ?
                new ErrorStatistics() :
                (ErrorStatistics) target;

        return ObjectCopier.copyTo(this, copy, copyBuilder);
    }

    @Override
    public Object copy(CopyBuilder copyBuilder) {
        return copyTo(new ErrorStatistics(), copyBuilder);
    }
}
