/*
 * Copyright 2021 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.hft.stuttgart.quality.model;

import org.citygml4j.builder.copy.CopyBuilder;
import org.citygml4j.builder.copy.ObjectCopier;
import org.citygml4j.model.common.base.ModelObjects;
import org.citygml4j.model.common.child.ChildList;

import java.util.List;

public class ValidationResult extends AbstractDataType {
    private ValidationProperty validation;
    private List<AbstractError> errors;
    private ResultType resultType;

    public ValidationProperty getValidation() {
        return validation;
    }

    public void setValidation(ValidationProperty validation) {
        this.validation = ModelObjects.setParent(validation, this);
    }

    public boolean isSetErrors() {
        return errors != null && !errors.isEmpty();
    }

    public List<AbstractError> getErrors() {
        if (errors == null) {
            errors = new ChildList<>(this);
        }

        return errors;
    }

    public void setErrors(List<AbstractError> errors) {
        this.errors = ModelObjects.setParent(errors, this);
    }

    public ResultType getResultType() {
        return resultType;
    }

    public void setResultType(ResultType resultType) {
        this.resultType = resultType;
    }

    @Override
    public Object copyTo(Object target, CopyBuilder copyBuilder) {
        ValidationResult copy = target == null ?
                new ValidationResult() :
                (ValidationResult) target;

        return ObjectCopier.copyTo(this, copy, copyBuilder);
    }

    @Override
    public Object copy(CopyBuilder copyBuilder) {
        return copyTo(new ValidationResult(), copyBuilder);
    }
}
